ModelBufferAllocator

Struct ModelBufferAllocator 

pub struct ModelBufferAllocator { /* private fields */ }
Model Buffer allocator.

Each frame the sequence is:

  1. [reset()] — clear the staging vector
  2. [allocate()] — push uniforms and return byte offsets
  3. Caller uploads via ResourceManager::upload_model_buffer()

Implementations

Source

impl ModelBufferAllocator

pub fn new() -> Self

pub fn reset(&mut self)

Reset at the beginning of each frame.

pub fn buffer_handle(&self) -> &BufferRef

pub fn uniform_stride() -> NonZero<u64>

pub fn allocate(&mut self, data: DynamicModelUniforms) -> u32

Allocate a model uniform slot, returning the byte offset.

pub fn shrink_to_fit(&mut self)

Shrink the capacity to fit the current number of uniforms. Only intended to be called during scene transitions when we expect a significant drop in the number of active models, to free up GPU memory. Not called every frame to avoid fragmentation and performance overhead.

pub fn flush_to_buffer( &self, device: &Device, queue: &Queue, gpu_buffers: &mut SlotMap<GpuBufferHandle, GpuBuffer>, buffer_index: &mut FxHashMap<u64, GpuBufferHandle>, frame_index: u64, ) -> bool

pub fn host_data(&self) -> &[DynamicModelUniforms]

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool