pub struct ModelBufferAllocator { /* private fields */ }Expand description
Model Buffer allocator.
Each frame the sequence is:
- [
reset()] — clear the staging vector - [
allocate()] — push uniforms and return byte offsets - Caller uploads via
ResourceManager::upload_model_buffer()
Implementations
Sourceimpl ModelBufferAllocator
impl ModelBufferAllocator
pub fn new() -> Self
pub fn buffer_handle(&self) -> &BufferRef
pub fn uniform_stride() -> NonZero<u64>
Sourcepub fn allocate(&mut self, data: DynamicModelUniforms) -> u32
pub fn allocate(&mut self, data: DynamicModelUniforms) -> u32
Allocate a model uniform slot, returning the byte offset.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrink the capacity to fit the current number of uniforms. Only intended to be called during scene transitions when we expect a significant drop in the number of active models, to free up GPU memory. Not called every frame to avoid fragmentation and performance overhead.
pub fn flush_to_buffer( &self, device: &Device, queue: &Queue, gpu_buffers: &mut SlotMap<GpuBufferHandle, GpuBuffer>, buffer_index: &mut FxHashMap<u64, GpuBufferHandle>, frame_index: u64, ) -> bool
pub fn host_data(&self) -> &[DynamicModelUniforms]
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool